# Hugging Face

`sieves` supports [Hugging Face](https://huggingface.co/) `pipelines` for zero-shot classification.

## Usage

```python
--8<-- "sieves/tests/docs/test_model_wrapper_usage.py:huggingface-usage"
```

---

::: sieves.model_wrappers.huggingface_.HuggingFace
